pub struct PluginToolResult {
pub tool_call_id: String,
pub content: Vec<ToolResultContent>,
pub is_error: bool,
pub summary: Option<String>,
pub post_persist_actions: Vec<PostPersistAction>,
}Fields
tool_call_id: Stringcontent: Vec<ToolResultContent>is_error: boolsummary: Option<String>post_persist_actions: Vec<PostPersistAction>Tier-2 actions to run after this tool result is persisted to the caller’s session history. Drained by the agent loop once the tool result reaches the caller’s history.